Biblicus Documentation
======================

Corpus management and retrieval evaluation in Python.

Contents
--------

.. toctree::
   :maxdepth: 2

   ARCHITECTURE
   ROADMAP
   FEATURE_INDEX
   CORPUS
   CORPUS_DESIGN
   USER_CONFIGURATION
   EXTRACTION
   TESTING
   BACKENDS
   DEMOS
   api
